@@ -13,6 +13,7 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_sts.type_defs import (
@@ -45,9 +46,10 @@ class Exceptions:
 
 class STSClient:
     """
-    [STS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client)
+    [STS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def assume_role(
@@ -64,7 +66,7 @@ class STSClient:
         TokenCode: str = None,
     ) -> AssumeRoleResponseTypeDef:
         """
-        [Client.assume_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.assume_role)
+        [Client.assume_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.assume_role)
         """
 
     def assume_role_with_saml(
@@ -77,7 +79,7 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
-        [Client.assume_role_with_saml documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Client.assume_role_with_saml documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.assume_role_with_saml)
         """
 
     def assume_role_with_web_identity(
@@ -91,19 +93,19 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
-        [Client.assume_role_with_web_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Client.assume_role_with_web_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.can_paginate)
         """
 
     def decode_authorization_message(
         self, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
         """
-        [Client.decode_authorization_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Client.decode_authorization_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.decode_authorization_message)
         """
 
     def generate_presigned_url(
@@ -114,17 +116,17 @@ class STSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.generate_presigned_url)
         """
 
     def get_access_key_info(self, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
-        [Client.get_access_key_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Client.get_access_key_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.get_access_key_info)
         """
 
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
         """
-        [Client.get_caller_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Client.get_caller_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.get_caller_identity)
         """
 
     def get_federation_token(
@@ -136,12 +138,12 @@ class STSClient:
         Tags: List[TagTypeDef] = None,
     ) -> GetFederationTokenResponseTypeDef:
         """
-        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.get_federation_token)
+        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.get_federation_token)
         """
 
     def get_session_token(
         self, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
     ) -> GetSessionTokenResponseTypeDef:
         """
-        [Client.get_session_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sts.html#STS.Client.get_session_token)
+        [Client.get_session_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/sts.html#STS.Client.get_session_token)
         """
